
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef zone_MSG_LIB_H
#define zone_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "zoneType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  ZONE_MBOX_NAME                  genomInstanceName("zone")

#define  ZONE_MAX_RQST_SIZE              200

#define  ZONE_MBOX_RQST_SIZE       \
 (BUF_SIZE(ZONE_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  ZONE_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  ZONE_MAX_REPLY_SIZE             200

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  ZONE_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(ZONE_MAX_REPLY_SIZE) \
   + BUF_SIZE(ZONE_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define ZONE_START_RQST 0
#define ZONE_GETSTARTPARAMS_RQST 1
#define ZONE_READZONEFILE_RQST 2
#define ZONE_SAVEZONEFILE_RQST 3
#define ZONE_BUILDNAVMAP_RQST 4
#define ZONE_SAVENAVMAP_RQST 5
#define ZONE_GETSEGLOCMAP_RQST 6
#define ZONE_GETZONEBYID_RQST 7
#define ZONE_GETZONEBYNAME_RQST 8
#define ZONE_MOBILETOMONITOR_RQST 9
#define ZONE_REMOVEMOBILE_RQST 10
#define ZONE_MONITORENTER_RQST 11
#define ZONE_MONITORLEAVE_RQST 12
#define ZONE_MONITORENTERZONEID_RQST 13
#define ZONE_MONITORLEAVEZONEID_RQST 14
#define ZONE_STOP_RQST 15
#define ZONE_GETTARGETDIRECTION_RQST 16
#define ZONE_SIMULPOS_RQST 17
#define ZONE_GETZONEFILE_RQST 18
#define ZONE_EXPORTOBSTSINNAVZONE_RQST 19
#define ZONE_STOPEXPORTOBST_RQST 20
#define ZONE_MONITOROBSTS_RQST 21
#define ZONE_STOPMONITOROBSTS_RQST 22
#define ZONE_GETOUT_RQST 23
#define ZONE_GETCURRENTTARGETZONE_RQST 24
#define ZONE_GETCURRENTSPECIALZONE_RQST 25
#define ZONE_GETCURRENTZONES_RQST 26
#define ZONE_ISINZONE_RQST 27
#define ZONE_ABORT_RQST 28


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS zoneClientInit (CLIENT_ID *pClientId);

STATUS zoneClientEnd (CLIENT_ID clientId);

int zoneAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int zoneAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int zoneAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS zoneStartRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_INIT *(in_initParams),
					 int replyTimeOut);

extern int zoneStartReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneStartRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_INIT *(in_initParams), 
					
					int *activity, int *bilan);

extern int zoneStartRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_INIT *(in_initParams), 
					
					int *activity,
					int *bilan);




extern STATUS zoneGetStartParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int zoneGetStartParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       ZONE_INIT *(out_initParams),
			       int *bilan);

int zoneGetStartParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 ZONE_INIT *(out_initParams),
				 int *bilan);




extern STATUS zoneReadZoneFileRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_FILE *(in_zoneFile),
					 int replyTimeOut);

extern int zoneReadZoneFileReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneReadZoneFileRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_FILE *(in_zoneFile), 
					
					int *activity, int *bilan);

extern int zoneReadZoneFileRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_FILE *(in_zoneFile), 
					
					int *activity,
					int *bilan);




extern STATUS zoneSaveZoneFileRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_TYPE *(in_zoneType),
					 int replyTimeOut);

extern int zoneSaveZoneFileReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneSaveZoneFileRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_TYPE *(in_zoneType), 
					
					int *activity, int *bilan);

extern int zoneSaveZoneFileRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_TYPE *(in_zoneType), 
					
					int *activity,
					int *bilan);




extern STATUS zoneBuildNavMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_SEGLOC_MAP *(in_whereSeglocMap),
					 int replyTimeOut);

extern int zoneBuildNavMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneBuildNavMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_SEGLOC_MAP *(in_whereSeglocMap), 
					
					int *activity, int *bilan);

extern int zoneBuildNavMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_SEGLOC_MAP *(in_whereSeglocMap), 
					
					int *activity,
					int *bilan);




extern STATUS zoneSaveNavMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_fileName),
					 int replyTimeOut);

extern int zoneSaveNavMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneSaveNavMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity, int *bilan);

extern int zoneSaveNavMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity,
					int *bilan);




extern STATUS zoneGetSeglocMapRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int zoneGetSeglocMapReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       ZONE_SEGLOC_MAP *(out_whereSeglocMap),
			       int *bilan);

int zoneGetSeglocMapRqstAndRcv (CLIENT_ID clientId, 
				  
				 ZONE_SEGLOC_MAP *(out_whereSeglocMap),
				 int *bilan);




extern STATUS zoneGetZoneByIdRqstSend (CLIENT_ID clientId, int *pRqstId,
					 int *(in_zoneId),
					 int replyTimeOut);

extern int zoneGetZoneByIdReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_PARAMS *(out_zoneParams),
				      int *activity, int *bilan);


extern int zoneGetZoneByIdRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					int *(in_zoneId), 
					ZONE_PARAMS *(out_zoneParams),
					int *activity, int *bilan);

extern int zoneGetZoneByIdRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					int *(in_zoneId), 
					ZONE_PARAMS *(out_zoneParams),
					int *activity,
					int *bilan);




extern STATUS zoneGetZoneByNameRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_zoneName),
					 int replyTimeOut);

extern int zoneGetZoneByNameReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_PARAMS *(out_zoneParams),
				      int *activity, int *bilan);


extern int zoneGetZoneByNameRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_zoneName), 
					ZONE_PARAMS *(out_zoneParams),
					int *activity, int *bilan);

extern int zoneGetZoneByNameRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_zoneName), 
					ZONE_PARAMS *(out_zoneParams),
					int *activity,
					int *bilan);




extern STATUS zoneMobileToMonitorRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_DESC *(in_mobileParams),
					 int replyTimeOut);

extern int zoneMobileToMonitorReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_MOBILE_ID *(out_mobileId),
				      int *activity, int *bilan);


extern int zoneMobileToMonitorRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_DESC *(in_mobileParams), 
					ZONE_MOBILE_ID *(out_mobileId),
					int *activity, int *bilan);

extern int zoneMobileToMonitorRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_DESC *(in_mobileParams), 
					ZONE_MOBILE_ID *(out_mobileId),
					int *activity,
					int *bilan);




extern STATUS zoneRemoveMobileRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_ID *(in_mobileId),
					 int replyTimeOut);

extern int zoneRemoveMobileReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneRemoveMobileRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_ID *(in_mobileId), 
					
					int *activity, int *bilan);

extern int zoneRemoveMobileRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_ID *(in_mobileId), 
					
					int *activity,
					int *bilan);




extern STATUS zoneMonitorEnterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_ID *(in_mobileId),
					 int replyTimeOut);

extern int zoneMonitorEnterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_IDENTITY *(out_zoneIdentity),
				      int *activity, int *bilan);


extern int zoneMonitorEnterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_ID *(in_mobileId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity, int *bilan);

extern int zoneMonitorEnterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_ID *(in_mobileId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity,
					int *bilan);




extern STATUS zoneMonitorLeaveRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_ID *(in_mobileId),
					 int replyTimeOut);

extern int zoneMonitorLeaveReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_IDENTITY *(out_zoneIdentity),
				      int *activity, int *bilan);


extern int zoneMonitorLeaveRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_ID *(in_mobileId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity, int *bilan);

extern int zoneMonitorLeaveRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_ID *(in_mobileId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity,
					int *bilan);




extern STATUS zoneMonitorEnterZoneIdRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId),
					 int replyTimeOut);

extern int zoneMonitorEnterZoneIdReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_IDENTITY *(out_zoneIdentity),
				      int *activity, int *bilan);


extern int zoneMonitorEnterZoneIdRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity, int *bilan);

extern int zoneMonitorEnterZoneIdRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity,
					int *bilan);




extern STATUS zoneMonitorLeaveZoneIdRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId),
					 int replyTimeOut);

extern int zoneMonitorLeaveZoneIdReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_IDENTITY *(out_zoneIdentity),
				      int *activity, int *bilan);


extern int zoneMonitorLeaveZoneIdRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity, int *bilan);

extern int zoneMonitorLeaveZoneIdRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity,
					int *bilan);




extern STATUS zoneStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int zoneStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int zoneStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS zoneGetTargetDirectionRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId),
					 int replyTimeOut);

extern int zoneGetTargetDirectionReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_ROBOT_TO_TARGET *(out_targetPos),
				      int *activity, int *bilan);


extern int zoneGetTargetDirectionRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId), 
					ZONE_ROBOT_TO_TARGET *(out_targetPos),
					int *activity, int *bilan);

extern int zoneGetTargetDirectionRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_ID *(in_mobileAndZoneId), 
					ZONE_ROBOT_TO_TARGET *(out_targetPos),
					int *activity,
					int *bilan);




extern STATUS zoneSimulPosRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_CONFIG *(in_simulPos),
					 int replyTimeOut);

extern int zoneSimulPosReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneSimulPosRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_CONFIG *(in_simulPos), 
					
					int *activity, int *bilan);

extern int zoneSimulPosRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_CONFIG *(in_simulPos), 
					
					int *activity,
					int *bilan);




extern STATUS zoneGetZoneFileRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int zoneGetZoneFileReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GEN_STRING128 *(out_fileName),
			       int *bilan);

int zoneGetZoneFileRqstAndRcv (CLIENT_ID clientId, 
				  
				 GEN_STRING128 *(out_fileName),
				 int *bilan);




extern STATUS zoneExportObstsInNavZoneRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_OBSTS_FIELD *(in_obstsField),
					 int replyTimeOut);

extern int zoneExportObstsInNavZoneReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int zoneExportObstsInNavZoneRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_OBSTS_FIELD *(in_obstsField), 
					
					int *activity, int *bilan);

extern int zoneExportObstsInNavZoneRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_OBSTS_FIELD *(in_obstsField), 
					
					int *activity,
					int *bilan);




extern STATUS zoneStopExportObstRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int zoneStopExportObstReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int zoneStopExportObstRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS zoneMonitorObstsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int zoneMonitorObstsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_OBST_STATE *(out_obstState),
				      int *activity, int *bilan);


extern int zoneMonitorObstsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					ZONE_OBST_STATE *(out_obstState),
					int *activity, int *bilan);

extern int zoneMonitorObstsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					ZONE_OBST_STATE *(out_obstState),
					int *activity,
					int *bilan);




extern STATUS zoneStopMonitorObstsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int zoneStopMonitorObstsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int zoneStopMonitorObstsRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS zoneGetOutRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_GET_OUT_FROM_OBST *(in_getOut),
					 int replyTimeOut);

extern int zoneGetOutReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_POINT *(out_outPoint),
				      int *activity, int *bilan);


extern int zoneGetOutRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_GET_OUT_FROM_OBST *(in_getOut), 
					ZONE_POINT *(out_outPoint),
					int *activity, int *bilan);

extern int zoneGetOutRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_GET_OUT_FROM_OBST *(in_getOut), 
					ZONE_POINT *(out_outPoint),
					int *activity,
					int *bilan);




extern STATUS zoneGetCurrentTargetZoneRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType),
					 int replyTimeOut);

extern int zoneGetCurrentTargetZoneReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_IDENTITY *(out_zoneIdentity),
				      int *activity, int *bilan);


extern int zoneGetCurrentTargetZoneRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity, int *bilan);

extern int zoneGetCurrentTargetZoneRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity,
					int *bilan);




extern STATUS zoneGetCurrentSpecialZoneRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType),
					 int replyTimeOut);

extern int zoneGetCurrentSpecialZoneReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_IDENTITY *(out_zoneIdentity),
				      int *activity, int *bilan);


extern int zoneGetCurrentSpecialZoneRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity, int *bilan);

extern int zoneGetCurrentSpecialZoneRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity,
					int *bilan);




extern STATUS zoneGetCurrentZonesRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType),
					 int replyTimeOut);

extern int zoneGetCurrentZonesReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_IDENTITY *(out_zoneIdentity),
				      int *activity, int *bilan);


extern int zoneGetCurrentZonesRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity, int *bilan);

extern int zoneGetCurrentZonesRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_MOBILE_AND_ZONE_TYPE *(in_mobileAndZoneType), 
					ZONE_IDENTITY *(out_zoneIdentity),
					int *activity,
					int *bilan);




extern STATUS zoneIsInZoneRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ZONE_TEST_INPUT *(in_zoneIdentityInput),
					 int replyTimeOut);

extern int zoneIsInZoneReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ZONE_TEST_OUTPUT *(out_res),
				      int *activity, int *bilan);


extern int zoneIsInZoneRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ZONE_TEST_INPUT *(in_zoneIdentityInput), 
					ZONE_TEST_OUTPUT *(out_res),
					int *activity, int *bilan);

extern int zoneIsInZoneRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ZONE_TEST_INPUT *(in_zoneIdentityInput), 
					ZONE_TEST_OUTPUT *(out_res),
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* zone_MSG_LIB_H */

